patch-prolog-compiler 0.4.9

Standalone Prolog compiler (plgc) — compiles .pl to native binaries via LLVM
docs.rs failed to build patch-prolog-compiler-0.4.9
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.